@@ -1,18 +1,15 @@
 """
 Implements the client that interacts with Customer.io"s App API using app keys.
 """
+
 import base64
+from typing import Dict, Literal, Optional, TypedDict, Union
 
-
-try:
-    from typing import Dict, Literal, Optional, TypedDict, Union
-except ImportError:
-    from typing_extensions import Dict, Literal, Optional, TypedDict, Union  # type: ignore
-
+from async_customerio._config import DEFAULT_REQUEST_TIMEOUT, RequestTimeout
 from async_customerio.client_base import AsyncClientBase
 from async_customerio.errors import AsyncCustomerIOError
 from async_customerio.regions import Region, Regions
-from async_customerio.utils import join_url
+from async_customerio.utils import join_url, to_dict
 
 
 IdentifierID = TypedDict("IdentifierID", {"id": Union[str, int]})
@@ -20,7 +17,12 @@ IdentifierEMAIL = TypedDict("IdentifierEMAIL", {"email": str})
 IdentifierCIOID = TypedDict("IdentifierCIOID", {"cio_id": Union[str, int]})
 CustomDevice = TypedDict(
     "CustomDevice",
-    {"token": str, "platform": Literal["ios", "android"], "last_used": Optional[int], "attributes": dict},
+    {
+        "token": str,
+        "platform": Literal["ios", "android"],
+        "last_used": Optional[int],
+        "attributes": dict,
+    },
 )
 
 
@@ -120,14 +122,7 @@ class SendEmailRequest:
             send_at="send_at",
             language="language",
         )
-
-        data = {}
-        for field, name in field_map.items():
-            value = getattr(self, field, None)
-            if value is not None:
-                data[name] = value
-
-        return data
+        return to_dict(field_map=field_map, instance=self)
 
 
 class SendPushRequest:
@@ -194,30 +189,95 @@ class SendPushRequest:
             device="custom_device",
             sound="sound",
         )
+        return to_dict(field_map=field_map, instance=self)
 
-        data = {}
-        for field, name in field_map.items():
-            value = getattr(self, field, None)
-            if value is not None:
-                data[name] = value
 
-        return data
+class SendSMSRequest:
+    """An object with all the options available for triggering a transactional SMS message."""
+
+    def __init__(
+        self,
+        transactional_message_id: Optional[Union[str, int]] = None,
+        to: Optional[str] = None,
+        identifiers: Optional[Union[IdentifierID, IdentifierEMAIL, IdentifierCIOID]] = None,
+        _from: Optional[str] = None,
+        language: Optional[str] = None,
+        message_data: Optional[dict] = None,
+        send_at: Optional[int] = None,
+        disable_message_retention: bool = False,
+        send_to_unsubscribed: bool = True,
+        queue_draft: bool = False,
+    ) -> None:
+        """Constructor of the SMS message object that is sent along with the request.
+
+        :param transactional_message_id: The transactional message template that you want to use for your message.
+        :param identifiers: Identifies the person represented by your transactional message by one of, and only one of,
+            ``IdentifierID``, ``IdentifierEMAIL``, ``IdentifierCIOID``.
+        :param _from: The phone number or sender ID that your SMS is from. This must be a verified phone number in your
+            Twilio account. This overrides the from address set within the transactional template (referenced by
+            ``transactional_message_id``). Phone numbers must be in E.164 format (e.g., +15551234567).
+        :param language: Overrides language preferences for the person you want to send your transactional message to.
+        :param message_data: A dictionary containing the key-value pairs referenced using **liquid** in your message.
+        :param send_at: A unix timestamp (seconds since epoch) determining when the message will be sent.
+        :param disable_message_retention: If true, the message body is not retained in delivery history. Default is set
+            to ``False``.
+        :param send_to_unsubscribed: If false, your message is not sent to unsubscribed recipients. Default is set to
+            ``True``.
+        :param queue_draft: If true, your transactional message is held as a draft in Customer.io and not sent directly
+            to your audience. Default is set to ``False``.
+        """
+
+        self.transactional_message_id = transactional_message_id
+        self.to = to
+        self.identifiers = identifiers
+        self._from = _from
+        self.language = language
+        self.message_data = message_data
+        self.send_at = send_at
+        self.disable_message_retention = disable_message_retention
+        self.send_to_unsubscribed = send_to_unsubscribed
+        self.queue_draft = queue_draft
+
+    def to_dict(self):
+        """Build a request payload from the object."""
+        field_map = dict(
+            # `from` is reserved keyword hence the object has the field
+            # `_from` but in the request payload we map it to `from`
+            _from="from",
+            # field name is the same as the payload field name
+            transactional_message_id="transactional_message_id",
+            to="to",
+            identifiers="identifiers",
+            disable_message_retention="disable_message_retention",
+            send_to_unsubscribed="send_to_unsubscribed",
+            queue_draft="queue_draft",
+            message_data="message_data",
+            send_at="send_at",
+            language="language",
+        )
+        return to_dict(field_map=field_map, instance=self)
 
 
 class AsyncAPIClient(AsyncClientBase):
     API_PREFIX = "/v1"
     SEND_EMAIL_ENDPOINT = "/send/email"
     SEND_PUSH_NOTIFICATION_ENDPOINT = "/send/push"
+    SEND_SMS_ENDPOINT = "/send/sms"
 
     def __init__(
-        self, key: str, url: Optional[str] = None, region: Region = Regions.US, retries: int = 3, timeout: int = 10
+        self,
+        key: str,
+        url: Optional[str] = None,
+        region: Region = Regions.US,
+        retries: int = 3,
+        request_timeout: RequestTimeout = DEFAULT_REQUEST_TIMEOUT,
     ):
         if not isinstance(region, Region):
             raise AsyncCustomerIOError("invalid region provided")
 
         self.key = key
         self.base_url = url or "https://{host}".format(host=region.api_host)
-        super().__init__(retries=retries, timeout=timeout)
+        super().__init__(retries=retries, request_timeout=request_timeout)
 
     async def send_email(self, request: SendEmailRequest) -> dict:
         if not isinstance(request, SendEmailRequest):
@@ -240,3 +300,14 @@ class AsyncAPIClient(AsyncClientBase):
             json_payload=request.to_dict(),
             headers={"Authorization": "Bearer {key}".format(key=self.key)},
         )
+
+    async def send_sms(self, request: SendSMSRequest) -> dict:
+        if not isinstance(request, SendSMSRequest):
+            raise AsyncCustomerIOError("invalid request provided")
+
+        return await self.send_request(
+            "POST",
+            join_url(self.base_url, self.API_PREFIX, self.SEND_SMS_ENDPOINT),
+            json_payload=request.to_dict(),
+            headers={"Authorization": "Bearer {key}".format(key=self.key)},
+        )
